var path = require('path');

module.exports = function(grunt) {

  grunt.initConfig({

    pkg: grunt.file.readJSON('package.json'),

    banner: '/*!\n' +
      '* Package: <%= pkg.name %> - v<%= pkg.version %> \n' +
      '* Description: <%= pkg.description %> \n' +
      '* Last build: <%= grunt.template.today("yyyy-mm-dd") %> \n' +
      '* @author <%= pkg.author %> \n' +
      '* @license <%= pkg.license %> \n'+
      '*/\n',

    // Clean the dist directory files
    clean: {
      all: ['assets/dist/*', 'languages/<%= pkg.name %>.pot'],
      styles: ['assets/dist/css/*'],
      scripts: ['assets/dist/js/*']
    },

    jshint: {
      files: ['assets/src/js/**/*.js'],
      options: {
        globals: {
          jQuery: true
        }
      }
    },

    // Concat all the user and admin scripts for development
    concat: {
      options: {
        stripBanners: true,
        banner: '<%= banner %>'
      },
      user_script: {
        src: ['assets/src/js/user/**/*.js'],
        dest: 'assets/dist/js/user.js'
      },
      admin_script: {
        src: ['assets/src/js/admin/**/*.js'],
        dest: 'assets/dist/js/admin.js'
      }
    },

    uglify: {
      options: {
        banner: '<%= banner %>'
      },
      user_script: {
        files: {
          'assets/dist/js/user.min.js': ['assets/dist/js/user.js']
        }
      },
      admin_script: {
        files: {
          'assets/dist/js/admin.min.js': ['assets/dist/js/admin.js']
        }
      }
    },

    sass: {
      dist: {
        options: {
          style: 'compressed'
        },
        files: {
          'assets/dist/css/user.css': 'assets/src/scss/user.scss',
          'assets/dist/css/admin.css': 'assets/src/scss/admin.scss'
        }
      }
    },

    watch: {
      scripts: {
        files: ['assets/src/js/**/*.js'],
        tasks: ['newer:jshint', 'concat', 'uglify'],
        options: { spawn: false }
      },
      styles: {
        files: ['assets/src/scss/**/*.scss'],
        tasks: ['sass'],
        options: { spawn: false }
      }
    },

    makepot: {
      target: {
        options: {
          type: 'wp-plugin',
          mainFile: '<%= pkg.name %>.php',
          domainPath: '/languages'
        }
      }
    }

  });

  // development tasks
  grunt.loadNpmTasks('grunt-contrib-clean');
  grunt.loadNpmTasks('grunt-contrib-jshint');
  grunt.loadNpmTasks('grunt-contrib-concat');
  grunt.loadNpmTasks('grunt-contrib-uglify');
  grunt.loadNpmTasks('grunt-contrib-sass');
  grunt.loadNpmTasks('grunt-contrib-watch');
  grunt.loadNpmTasks('grunt-newer');
  grunt.loadNpmTasks('grunt-wp-i18n');

  // register watch task
  grunt.registerTask('default', ['watch']);

  // register build task
  grunt.registerTask('build', ['clean:all', 'build-scripts', 'build-styles', 'makepot']);

  // partial build tasks
  grunt.registerTask('build-styles', ['sass']);
  grunt.registerTask('build-scripts', ['jshint', 'concat', 'uglify']);

};
